#
# spec file for package valgrind
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           valgrind
BuildRequires:  docbook-xsl-stylesheets docbook_4 gcc-c++ libxslt xorg-x11-devel
%ifarch x86_64 ppc64
BuildRequires:  glibc-devel-32bit
%endif
Url:            http://valgrind.org/
License:        GPLv2+
Group:          Development/Tools/Debuggers
Summary:        Memory Management Debugger
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Version:        3.6.1
Release:        1.3.1
Source0:        %{name}-%{version}.tar.bz2
# svn  di svn://svn.valgrind.org/valgrind/tags/VALGRIND_3_5_0 svn://svn.valgrind.org/valgrind/branches/VALGRIND_3_5_BRANCH > 3_5_BRANCH.diff
# svn  di svn://svn.valgrind.org/vex/tags/VEX_3_5_0 svn://svn.valgrind.org/vex/branches/VEX_3_5_BRANCH > VEX_3_5_BRANCH.diff
Patch1:         jit-register-unregister.diff
Patch2:         deprecated.diff
Patch3:         valgrind-3.5.90.svn11391-s390x-port.diff
%if %suse_version <= 1100
Provides:       valgrind-devel = %version
%endif
Provides:       callgrind = %version
Obsoletes:      callgrind < %version
ExclusiveArch:  %ix86 x86_64 ppc ppc64 s390x
%if %suse_version > 1100
%define building_docs 1
%else
%define building_docs 0
%endif

%description
Valgrind checks all memory operations in an application, like read,
write, malloc, new, free, and delete. Valgrind can find uses of
uninitialized memory, access to already freed memory, overflows,
illegal stack operations, memory leaks, and any illegal
new/malloc/free/delete commands. Another program in the package is
"cachegrind," a profiler based on the valgrind engine.

To use valgrind you should compile your application with "-g -O0"
compiler options. Afterwards you can use it with:

valgrind --tool=memcheck --sloppy-malloc=yes --leak-check=yes
--db-attach=yes my_application, for example.

More valgrind options can be listed via "valgrind --help". There is
also complete documentation in the /usr/share/doc/packages/valgrind/
directory. A debugged application runs slower and needs much more
memory, but is usually still usable. Valgrind is still in development,
but it has been successfully used to optimize several KDE applications.



Authors:
--------
    Julian Seward <jseward@acm.org>
    Cerion Armour-Brown
    Jeremy Fitzhardinge
    Tom Hughes
    Nicholas Nethercote
    Paul Mackerras
    Dirk Mueller
    Robert Walsh

%if %suse_version > 1100

%package devel
License:        GPLv2+
Summary:        Memory Management Debugger
Group:          Development/Tools/Debuggers
Requires:       %name = %version

%description devel
Valgrind checks all memory operations in an application, like read,
write, malloc, new, free, and delete. Valgrind can find uses of
uninitialized memory, access to already freed memory, overflows,
illegal stack operations, memory leaks, and any illegal
new/malloc/free/delete commands. Another program in the package is
"cachegrind," a profiler based on the valgrind engine.

To use valgrind you should compile your application with "-g -O0"
compiler options. Afterwards you can use it with:

valgrind --tool=memcheck --sloppy-malloc=yes --leak-check=yes
--db-attach=yes my_application, for example.

More valgrind options can be listed via "valgrind --help". There is
also complete documentation in the /usr/share/doc/packages/valgrind/
directory. A debugged application runs slower and needs much more
memory, but is usually still usable. Valgrind is still in development,
but it has been successfully used to optimize several KDE applications.



Authors:
--------
    Julian Seward <jseward@acm.org>
    Cerion Armour-Brown
    Jeremy Fitzhardinge
    Tom Hughes
    Nicholas Nethercote
    Paul Mackerras
    Dirk Mueller
    Robert Walsh

%endif

%prep
%setup -q -n %{name}-%{version}
cd VEX
cd ..
%patch1
%ifarch s390x
%patch3
%endif
# probably no longer needed, kept around already for a long time (2010-10-12)
#%patch2

%build
export CFLAGS="$RPM_OPT_FLAGS"
export CXXFLAGS="$RPM_OPT_FLAGS"
autoreconf -fi
export GDB=/usr/bin/gdb
%configure
make %{?jobs:-j%jobs}
%if %building_docs
pushd docs
    #make all-docs
    # building the docs needs network access at the moment :-(
    make FAQ.txt man-pages html-docs
popd
%endif

%install
make DESTDIR=$RPM_BUILD_ROOT install
mkdir -p $RPM_BUILD_ROOT/%_defaultdocdir
if test -d $RPM_BUILD_ROOT/usr/share/doc/valgrind; then
     mv $RPM_BUILD_ROOT/usr/share/doc/valgrind $RPM_BUILD_ROOT/%_defaultdocdir
fi
mkdir -p $RPM_BUILD_ROOT/usr/share/doc/packages/%name
cp -a README* NEWS AUTHORS COPYING COPYING.DOCS $RPM_BUILD_ROOT/%_defaultdocdir/%name

%files
%defattr(-,root,root)
/usr/bin/*
%doc %_defaultdocdir/%name
%_libdir/valgrind
%doc %_mandir/*/*

%if %suse_version > 1100

%files devel
%defattr(-,root,root)
%endif

/usr/include/valgrind
/usr/%_lib/pkgconfig/valgrind.pc

%changelog
* Wed Mar 16 2011 dmueller@suse.de
- update to 3.6.1 (bnc#679106):
  3.6.1 is a bug fix release.  It adds support for some SSE4
  instructions that were omitted in 3.6.0 due to lack of time.  Initial
  support for glibc-2.13 has been added.  A number of bugs causing
  crashing or assertion failures have been fixed.
* Fri Oct 22 2010 dmueller@suse.de
- update to 3.6.0:
  3.6.0 is a feature release with many significant improvements and the
  usual collection of bug fixes. See the NEWS file for details.
* Thu Oct 21 2010 dmueller@suse.de
- apparently gcc-32bit does not exist on old code streams, but
  it seems to work without it as well
* Wed Oct 20 2010 dmueller@suse.de
- disable building docs until I find a way to build them without
  network access
* Wed Oct 13 2010 dmueller@suse.de
- add s390x port (FATE#310036)
- update to 3.6.0 snapshot:
  - Valgrind runs much faster when the --smc-check=all option is given.
  - Cachegrind has a new processing script, cg_diff, which finds the
    difference between two profiles.  It's very useful for evaluating the
    performance effects of a change in a program.
    Related to this change, the meaning of cg_annotate's (rarely-used)
  - -threshold option has changed; this is unlikely to affect many people, if
    you do use it please see the user manual for details.
  - Callgrind now can do branch prediction simulation, similar to Cachegrind.
    In addition, it optionally can count the number of executed global bus events.
    Both can be used for a better approximation of a "Cycle Estimation" as
    derived event (you need to update the event formula in KCachegrind yourself).
  - Cachegrind and Callgrind now refer to the LL (last-level) cache rather
    than the L2 cache.  This is to accommodate machines with three levels of
    caches -- if Cachegrind/Callgrind auto-detects the cache configuration of
    such a machine it will run the simulation as if the L2 cache isn't
    present.  This means the results are less likely to match the true result
    for the machine, but Cachegrind/Callgrind's results are already only
    approximate, and should not be considered authoritative.  The results are
    still useful for giving a general idea about a program's locality.
  - Massif has a new option, --pages-as-heap, which is disabled by default.
    When enabled, instead of tracking allocations at the level of heap blocks
    (as allocated with malloc/new/new[]), it instead tracks memory allocations
    at the level of memory pages (as mapped by mmap, brk, etc).  Each mapped
    page is treated as its own block.  Interpreting the page-level output is
    harder than the heap-level output, but this option is useful if you want
    to account for every byte of memory used by a program.
  - Added new memcheck command-line option --show-possibly-lost.
  - Support for analyzing programs running under Wine with has been improved.
    The header files <valgrind/valgrind.h>, <valgrind/memcheck.h> and
    <valgrind/drd.h> can now be used in Windows-programs compiled with MinGW
    or one of the Microsoft Visual Studio compilers.
  - DRD does now have two new command-line options: --free-is-write and
  - -trace-alloc. The former allows to detect reading from already freed
    memory, and the latter allows to trace all memory allocations and
    deallocations.
  - Several new annotations have been added in DRD: custom barrier
    implementations can now be annotated and benign races on static variables
    too.
  - The happens before / happens after annotations in DRD have been made more
    powerful such that these can now also be used to annotate e.g. a smart
    pointer implementation.
* Thu Sep 23 2010 dmueller@suse.de
- increase stack size (bnc#640793)
* Fri May  7 2010 dmueller@suse.de
- fix build for ppc64
* Mon Apr 26 2010 dmueller@suse.de
- handle pthread apps better (bnc#599585)
- prefer CFI for better stack unwinding (bnc#559061)
* Fri Mar 26 2010 dmueller@suse.de
- handle inotify_init1 (bnc#558964)
* Wed Jan  6 2010 dmueller@suse.de
- fix build against glibc 2.11
* Wed Dec  2 2009 dmueller@suse.de
- update and reenable jit-register-unregister.diff
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Tue Sep  8 2009 dmueller@suse.de
- update to 3.5.0:
  * Support for glibc 2.10, gcc 4.5 has been added.
  * Improvements and simplifications to Memcheck's leak checker.
  * Clarification and simplifications in various aspects of Valgrind's
    text output.
  * XML output for Helgrind and Ptrcheck.
  * Performance and stability improvements for Helgrind and DRD.
  * Genuinely atomic support for x86/amd64/ppc atomic instructions.
  * A new experimental tool, BBV, useful for computer architecture
    research.
  * Improved Wine support, including ability to read Windows PDB
    debuginfo.
* Fri Mar 13 2009 dmueller@suse.de
- update to 3.4.1 (bnc#479701):
  * 3.4.1 is a bug-fix release that fixes some regressions and
  assertion failures in debug info reading in 3.4.0, most notably
  incorrect stack traces on amd64-linux on older (glibc-2.3 based)
  systems. Various other debug info problems are also fixed. A
  number of bugs in the exp-ptrcheck tool introduced in 3.4.0
  have been fixed.
* Fri Jan 23 2009 dmueller@suse.de
- update to 3.4.0:
  * http://www.valgrind.org/docs/manual/dist.news.html
* Sun Nov 23 2008 dmueller@suse.de
- update suppressions
* Thu Nov 20 2008 dmueller@suse.de
- fix .valgrindrc reading vulnerability (CVE-2008-4865, bnc#445013)
- add support for glibc 2.9
* Wed Nov  5 2008 dmueller@suse.de
- add syscall wrappers for pipe2
* Tue Jun 24 2008 schwab@suse.de
- Add fadvice64 wrapper.
* Sun Jun 22 2008 dmueller@suse.de
- update to 3.3.1:
    n-i-bz  Massif segfaults at exit
    n-i-bz  Memcheck asserts on Altivec code
    n-i-bz  fix sizeof bug in Helgrind
    n-i-bz  check fd on sys_llseek
    n-i-bz  update syscall lists to kernel 2.6.23.1
    n-i-bz  support sys_sync_file_range
    n-i-bz  handle sys_sysinfo, sys_getresuid, sys_getresgid on ppc64-linux
    n-i-bz  intercept memcpy in 64-bit ld.so's
    n-i-bz  Fix wrappers for sys_{futimesat,utimensat}
    n-i-bz  Minor false-error avoidance fixes for Memcheck
    n-i-bz  libmpiwrap.c: add a wrapper for MPI_Waitany
    n-i-bz  helgrind support for glibc-2.8
    n-i-bz  partial fix for mc_leakcheck.c:698 assert:
    'lc_shadows[i]->data + lc_shadows[i] ...
    n-i-bz  Massif/Cachegrind output corruption when programs fork
    n-i-bz  register allocator fix: handle spill stores correctly
    n-i-bz  add support for PA6T PowerPC CPUs
    126389  vex x86->IR: 0xF 0xAE (FXRSTOR)
    158525  ==126389
    152818  vex x86->IR: 0xF3 0xAC (repz lodsb)
    153196  vex x86->IR: 0xF2 0xA6 (repnz cmpsb)
    155011  vex x86->IR: 0xCF (iret)
    155091  Warning [...] unhandled DW_OP_ opcode 0x23
    156960  ==155901
    155528  support Core2/SSSE3 insns on x86/amd64
    155929  ms_print fails on massif outputs containing long lines
    157665  valgrind fails on shmdt(0) after shmat to 0
    157748  support x86 PUSHFW/POPFW
    158212  helgrind: handle pthread_rwlock_try{rd,wr}lock.
    158425  sys_poll incorrectly emulated when RES==0
    158744  vex amd64->IR: 0xF0 0x41 0xF 0xC0 (xaddb)
    160907  Support for a couple of recent Linux syscalls
    161285  Patch -- support for eventfd() syscall
    161378  illegal opcode in debug libm (FUCOMPP)
    160136  ==161378
    161487  number of suppressions files is limited to 10
    162386  ms_print typo in milliseconds time unit for massif
    161036  exp-drd: client allocated memory was never freed
    162663  signalfd_wrapper fails on 64bit linux
* Sun Apr 27 2008 dmueller@suse.de
- update glibc 2.8 support
* Sun Dec 16 2007 dmueller@suse.de
- readd deprecated #define's (#348337)
* Wed Dec 12 2007 dmueller@suse.de
- update to 3.3.0 (final):
  * last minute bugfixes
* Thu Dec  6 2007 dmueller@suse.de
- update jit-support patch
* Mon Dec  3 2007 dmueller@suse.de
- update to 3.3.0 RC1:
  - Helgrind works again
  - Massif has been majorly overhauled
  - Cachegrind now does branch-prediction profiling
  - New experimental tools Omega and DRD
  - Many small refinements to stability, scalability and performance
  - Somewhat restructured documentation
  - Many bug fixes
* Mon Nov 26 2007 dmueller@suse.de
- fix build against glibc 2.7
* Fri Sep 14 2007 dmueller@suse.de
- fix divisions by zero in massif (#310234)
* Wed Sep 12 2007 dmueller@suse.de
- fix build on ppc64 again
- update suppressions
* Fri Aug 24 2007 dmueller@suse.de
- fix valgrind on x86_64 (#296803)
* Tue Aug 21 2007 dmueller@suse.de
- suppression update
* Tue Jul 24 2007 dmueller@suse.de
- update suppression file
* Mon Jul  9 2007 dmueller@suse.de
- support JIT runtimes (#289490)
* Tue Jul  3 2007 dmueller@suse.de
- update suppression file (#287090)
* Wed May 23 2007 dmueller@suse.de
- build against glibc 2.6
* Thu Apr  5 2007 dmueller@suse.de
- split into -devel subpackage
* Fri Mar 30 2007 dmueller@suse.de
- add patch to track undefinedness in environment (#249676)
* Tue Jan 30 2007 dmueller@suse.de
- update to 3.2.3:
  * fixes two serious regressions introduced in 3.2.2
  * intercept stpcpy_chk (#234247)
- fix openat syscall wrapper (#240225)
* Thu Jan 25 2007 dmueller@suse.de
- intercept stpcpy_chk and memrchr as well (#234347)
* Tue Jan 23 2007 dmueller@suse.de
- switch to gcc-32bit on x86_64
* Mon Jan 22 2007 dmueller@suse.de
- update to 3.2.2:
  * many fixes for ppc 32/64 (#fate 301640)
* Tue Oct 17 2006 dmueller@suse.de
- disable omega plugin for ppc/ppc64
* Mon Oct 16 2006 dmueller@suse.de
- update to 3.2 BRANCH:
  * support glibc 2.5
  * update suppressions
- add omega plugin
* Sat Sep 16 2006 dmueller@suse.de
- update to 3.2.1:
  * suppresion updates
* Fri Sep 15 2006 dmueller@suse.de
- update to 3.2.1rc1:
  * about 36 bugfixes
* Wed Sep 13 2006 stbinner@suse.de
- fix build with < Factory
* Mon Aug 28 2006 dmueller@suse.de
- fix suppressions
- update drd plugin
* Thu Aug 24 2006 dmueller@suse.de
- add experimental drd plugin
- fix build on x86_64
* Wed Aug  2 2006 dmueller@suse.de
- also fix multibyte NOP parsing for x86_64
* Tue Aug  1 2006 dmueller@suse.de
- add patch to handle multibyte NOPs as generated by
  recent binutils
* Wed Jun  7 2006 dmueller@suse.de
- update to 3.2.0 final
  * only marginal changes since rc1
* Tue May 30 2006 dmueller@suse.de
- update to 3.2.0 rc1:
  * ppc64 support
  * callgrind now integrated part
  * massive performance improvements
  * lots of emulation fixlets
* Thu Mar 16 2006 dmueller@suse.de
- update to 3.1.1 (FATE #300493)
* Mon Mar  6 2006 dmueller@suse.de
- various updates from branch to fix PPC32 support
* Mon Feb  6 2006 dmueller@suse.de
- Fix GDB support
* Mon Feb  6 2006 dmueller@suse.de
- Reduce BuildRequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan  4 2006 dmueller@suse.de
- update to 3.1 branch
* Fri Dec  9 2005 dmueller@suse.de
- fix strict-aliasing issue
* Mon Nov 28 2005 dmueller@suse.de
- 3.1.0 final update
* Mon Nov 21 2005 dmueller@suse.de
- 3.1.0 RC1 update
* Thu Nov 10 2005 dmueller@suse.de
- update to 3.1 SVN
* Tue Nov  8 2005 dmueller@suse.de
- add hack to make valgrind work with apps that require executable stack
* Thu Sep 15 2005 dmueller@suse.de
- update 3.0.1 final
* Thu Aug 25 2005 dmueller@suse.de
- make massif work again
* Sun Aug 21 2005 dmueller@suse.de
- fix trace-children=yes failure
- add default suppressions for SL 10
* Mon Aug 15 2005 dmueller@suse.de
- regenerate VEX offset headers, otherwise it just hangs
* Fri Aug 12 2005 dmueller@suse.de
- update to 3.0 branch to make it work on non-SSE platforms (#104181)
* Fri Aug  5 2005 dmueller@suse.de
- initial package of 3.0
